function [p,n,ci]=anova1_bernoulli(x,group,alpha)
% anova1_bernoulli One-way analysis of variance (ANOVA) for Bernoulli random variables
%    anova1_bernoulli performs a one-way ANOVA for comparing the proportion of two or more groups of data.
%
% It draws a boxplot with the alpha-confidence intervals for the proportion of each group.

clf
dbox=.3;

[g,i,j]=unique(group);
ng=length(g);

p=NaN(ng,1);
n=NaN(ng,1);
ci=NaN(ng,2);
for l=1:ng
    k=find(j==l);
    n(l)=length(k);
    p(l)=sum(x(k))/n(l);
    q=1-p(l);

    if p(l)*q>0
        ci(l,:)=norminv([(1-alpha)/2,1-(1-alpha)/2],p(l),sqrt(p(l)*q/n(l)));
        % mean
        line([l-dbox,l+dbox],[p(l),p(l)],'linestyle','--');
        % alpha-ci box
        line([l-dbox,l+dbox,l+dbox,l-dbox,l-dbox],[ci(l,1),ci(l,1),ci(l,2),ci(l,2),ci(l,1)]);
        % guide lines
        line([0,ng+1],[ci(l,1),ci(l,1)],'linestyle',':');
        line([0,ng+1],[ci(l,2),ci(l,2)],'linestyle',':');
    end
end
set(gca,'xtick',1:ng,'xticklabel',g);
rotateXLabels(gca,15);
ax=axis;
axis([0,ng+1,ax(3:4)])
ylabel(sprintf('proportion''s means and %d%% conf. int.',100*alpha))
